//
//  IgnorableDatePickerViewExampleViewController.m
//  IgnorableDatePickerViewExample
//
//  Created by Jaymie Strecker at Kosada Incorporated on 10/22/11.
//
//  This is free and unencumbered software released into the public domain.
//  
//  Anyone is free to copy, modify, publish, use, compile, sell, or
//  distribute this software, either in source code form or as a compiled
//  binary, for any purpose, commercial or non-commercial, and by any
//  means.
//  
//  In jurisdictions that recognize copyright laws, the author or authors
//  of this software dedicate any and all copyright interest in the
//  software to the public domain. We make this dedication for the benefit
//  of the public at large and to the detriment of our heirs and
//  successors. We intend this dedication to be an overt act of
//  relinquishment in perpetuity of all present and future rights to this
//  software under copyright law.
//  
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
//  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
//  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
//  IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
//  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
//  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
//  OTHER DEALINGS IN THE SOFTWARE.
//  
//  For more information, please refer to <http://unlicense.org/>

#import "IgnorableDatePickerViewExampleViewController.h"


@implementation IgnorableDatePickerViewExampleViewController

@synthesize tableView, startDateCell, endDateCell, echoCell, startDatePicker, endDatePicker;

- (void)viewDidLoad
{
	tableView.dataSource = self;
	tableView.delegate = self;
	
	// Allow scroll events to reach the UIPickerView (after holding down on the UIPickerView for a short time)
	// http://www.alexc.me/uiscrollview-and-uidatepicker/153/
	tableView.canCancelContentTouches = NO;
	
	startDatePicker.labelText = @"Start Date";
	endDatePicker.labelText = @"End Date";
}

- (IBAction)echo:(id)sender
{
	[[[[UIAlertView alloc] 
	   initWithTitle:@"Your dates" 
	   message:[NSString stringWithFormat:@"Start date: %@\nEnd date: %@", startDatePicker.dateString, endDatePicker.dateString]
	   delegate:nil cancelButtonTitle:@"OK" otherButtonTitles:nil]
	  autorelease]
	 show];
}

- (UITableViewCell *)cellForIndexPath:(NSIndexPath *)indexPath
{
	switch (indexPath.row)
	{
		case 0:
			return echoCell;
		case 1:
			return startDateCell;
		case 2:
			return endDateCell;
		default:
			return nil;
	}
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section 
{
	return 3;
}

- (UITableViewCell *)tableView:(UITableView *)aTableView cellForRowAtIndexPath:(NSIndexPath *)indexPath 
{
	return [self cellForIndexPath:indexPath];
}

- (CGFloat)tableView:(UITableView *)aTableView heightForRowAtIndexPath:(NSIndexPath *)indexPath
{
	UITableViewCell *cell = [self cellForIndexPath:indexPath];
	return cell.bounds.size.height;
}

- (void)dealloc
{
	[tableView release];
	[startDateCell release];
	[endDateCell release];
	[echoCell release];
	[startDatePicker release];
	[endDatePicker release];
    [super dealloc];
}

@end
